"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const CSpellSettingsServer_1 = require("./CSpellSettingsServer");
const DefaultSettings_1 = require("./DefaultSettings");
const path = __importStar(require("path"));
const { normalizeSettings } = CSpellSettingsServer_1.__testing__;
const rootCspellLib = path.resolve(path.join(__dirname, '../..'));
const samplesDir = path.resolve(rootCspellLib, 'samples');
const samplesSrc = path.join(samplesDir, 'src');
jest.mock('../util/logger');
describe('Validate CSpellSettingsServer', () => {
    test('tests mergeSettings with conflicting "name"', () => {
        const left = { name: 'Left' };
        const right = { name: 'Right' };
        expect(CSpellSettingsServer_1.mergeSettings(left, right)).toEqual({
            name: 'Left|Right',
            id: '|',
            enabledLanguageIds: [],
            languageSettings: [],
            source: { name: 'Left|Right', sources: [left, right] },
        });
    });
    test('tests mergeSettings with conflicting "id"', () => {
        const left = { id: 'left' };
        const enabled = { id: 'enabledId', name: 'enabledName', enabled: true };
        expect(CSpellSettingsServer_1.mergeSettings(left, enabled)).toEqual({
            enabled: true,
            name: '|enabledName',
            id: 'left|enabledId',
            enabledLanguageIds: [],
            languageSettings: [],
            source: { name: 'left|enabledName', sources: [left, enabled] },
        });
    });
    test('tests mergeSettings with conflicting "enabled"', () => {
        const right = { id: 'right', enabled: false };
        const left = { id: 'left', enabled: true };
        expect(CSpellSettingsServer_1.mergeSettings({}, right)).toEqual(right);
        expect(CSpellSettingsServer_1.mergeSettings(left, {})).toEqual(left);
        expect(CSpellSettingsServer_1.mergeSettings(left, right)).toEqual({
            enabled: right.enabled,
            name: '|',
            id: [left.id, right.id].join('|'),
            enabledLanguageIds: [],
            languageSettings: [],
            source: { name: 'left|right', sources: [left, right] },
        });
    });
    test('tests mergeSettings with inline object', () => {
        expect(CSpellSettingsServer_1.mergeSettings({ enabled: true }, { enabled: false })).toEqual({
            enabled: false,
            name: '|',
            id: '|',
            enabledLanguageIds: [],
            languageSettings: [],
            source: { name: 'left|right', sources: [{ enabled: true }, { enabled: false }] },
        });
    });
    test('tests mergeSettings with ignorePaths, files, and overrides', () => {
        var _a, _b, _c;
        const left = {
            id: 'left',
            files: ['left/**/*.*'],
            ignorePaths: ['node_modules'],
            overrides: [
                {
                    filename: '*.ts',
                    dictionaries: ['ts-extra'],
                },
            ],
        };
        const right = {
            id: 'right',
            enabled: true,
            files: ['right/**/*.*'],
            overrides: [{ filename: '*.jsxx', languageId: 'javascript' }], // cspell:ignore jsxx
        };
        expect(CSpellSettingsServer_1.mergeSettings({}, right)).toEqual(right);
        expect(CSpellSettingsServer_1.mergeSettings(left, {})).toEqual(left);
        expect(CSpellSettingsServer_1.mergeSettings(left, right)).toEqual({
            enabled: right.enabled,
            name: '|',
            id: [left.id, right.id].join('|'),
            enabledLanguageIds: [],
            languageSettings: [],
            files: (_a = left.files) === null || _a === void 0 ? void 0 : _a.concat(right.files || []),
            ignorePaths: (_b = left.ignorePaths) === null || _b === void 0 ? void 0 : _b.concat(right.ignorePaths || []),
            overrides: (_c = left.overrides) === null || _c === void 0 ? void 0 : _c.concat(right.overrides || []),
            source: { name: 'left|right', sources: [left, right] },
        });
    });
    test('tests mergeSettings with ignorePaths, files, and overrides compatibility', () => {
        var _a;
        const left = {
            id: 'left',
            files: ['left/**/*.*'],
            ignorePaths: ['node_modules'],
            overrides: [
                {
                    filename: '*.ts',
                    dictionaries: ['ts-extra'],
                },
            ],
        };
        const right = {
            id: 'right',
            version: '0.1',
            enabled: true,
            files: ['right/**/*.*'],
            ignorePaths: ['node_modules'],
            overrides: [{ filename: '*.jsxx', languageId: 'javascript' }], // cspell:ignore jsxx
        };
        expect(CSpellSettingsServer_1.mergeSettings({}, right)).toEqual(right);
        expect(CSpellSettingsServer_1.mergeSettings(left, {})).toEqual(left);
        expect(CSpellSettingsServer_1.mergeSettings(left, right)).toEqual({
            enabled: right.enabled,
            name: '|',
            id: [left.id, right.id].join('|'),
            version: right.version,
            enabledLanguageIds: [],
            languageSettings: [],
            files: (_a = left.files) === null || _a === void 0 ? void 0 : _a.concat(right.files || []),
            ignorePaths: right.ignorePaths,
            overrides: right.overrides,
            source: { name: 'left|right', sources: [left, right] },
        });
    });
    test('tests mergeSettings when left/right are the same', () => {
        expect(CSpellSettingsServer_1.mergeSettings(DefaultSettings_1._defaultSettings, DefaultSettings_1._defaultSettings)).toBe(DefaultSettings_1._defaultSettings);
    });
    test('tests mergeSettings when lefts are the same', () => {
        const base = CSpellSettingsServer_1.mergeSettings(DefaultSettings_1._defaultSettings, {});
        const setting1 = CSpellSettingsServer_1.mergeSettings(base, {});
        const setting2 = CSpellSettingsServer_1.mergeSettings(base, setting1);
        expect(setting2).toBe(setting1);
        const setting3 = CSpellSettingsServer_1.mergeSettings(DefaultSettings_1._defaultSettings, setting1);
        expect(setting3).toBe(setting1);
    });
    test('tests mergeSettings when rights are the same', () => {
        const base = CSpellSettingsServer_1.mergeSettings(DefaultSettings_1._defaultSettings, { id: 'right' });
        const setting1 = CSpellSettingsServer_1.mergeSettings({ id: 'setting1' }, base);
        const setting2 = CSpellSettingsServer_1.mergeSettings(setting1, base);
        expect(setting2).toBe(setting1);
        const setting3 = CSpellSettingsServer_1.mergeSettings(DefaultSettings_1._defaultSettings, setting1);
        expect(setting3).not.toBe(setting1);
        const setting4 = CSpellSettingsServer_1.mergeSettings(setting3, base);
        expect(setting4).toBe(setting3);
    });
    test('tests loading a missing cSpell.json file', () => {
        var _a, _b;
        const filename = path.join(__dirname, '..', '..', 'cspell.config.json');
        const settings = CSpellSettingsServer_1.readSettings(filename);
        expect((_a = settings.__importRef) === null || _a === void 0 ? void 0 : _a.filename).toBe(path.resolve(filename));
        expect((_b = settings.__importRef) === null || _b === void 0 ? void 0 : _b.error).toBeUndefined();
        expect(settings.import).toBeUndefined();
    });
    test('tests loading project cspell.json file', () => {
        const filename = path.join(__dirname, '..', '..', 'samples', 'linked', 'cspell-missing.json');
        const settings = CSpellSettingsServer_1.readSettings(filename);
        expect(Object.keys(settings)).not.toHaveLength(0);
        expect(settings.words).toBeUndefined();
    });
    test('tests loading a cSpell.json file', () => {
        const filename = path.join(__dirname, '..', '..', 'samples', 'linked', 'cspell-import.json');
        const settings = CSpellSettingsServer_1.readSettings(filename);
        expect(Object.keys(settings)).not.toHaveLength(0);
        expect(settings.words).toEqual(expect.arrayContaining(['import']));
    });
    test('tests loading a cSpell.json with multiple imports file', () => {
        const filename = path.join(__dirname, '..', '..', 'samples', 'linked', 'cspell-imports.json');
        const settings = CSpellSettingsServer_1.readSettings(filename);
        expect(Object.keys(settings)).not.toHaveLength(0);
        expect(settings.words).toEqual(expect.arrayContaining(['import']));
        expect(settings.words).toEqual(expect.arrayContaining(['imports']));
        // cspell:word leuk
        expect(settings.words).toEqual(expect.arrayContaining(['leuk']));
    });
    test('tests loading a cSpell.json with a missing import file', () => {
        var _a, _b;
        const filename = path.join(__dirname, '..', '..', 'samples', 'linked', 'cspell-import-missing.json');
        const settings = CSpellSettingsServer_1.readSettings(filename);
        expect((_a = settings.__importRef) === null || _a === void 0 ? void 0 : _a.filename).toBe(path.resolve(filename));
        expect((_b = settings.__imports) === null || _b === void 0 ? void 0 : _b.size).toBe(2);
        const errors = CSpellSettingsServer_1.extractImportErrors(settings);
        expect(errors).toHaveLength(1);
        expect(errors.map((ref) => ref.error.toString())).toContainEqual(expect.stringMatching('intentionally-missing-file.json'));
        expect(errors.map((ref) => ref.error.toString())).toContainEqual(expect.stringMatching('Failed to read'));
    });
    test('makes sure global settings is an object', () => {
        const settings = CSpellSettingsServer_1.getGlobalSettings();
        expect(Object.keys(settings)).not.toHaveLength(0);
        const merged = CSpellSettingsServer_1.mergeSettings(DefaultSettings_1.getDefaultSettings(), CSpellSettingsServer_1.getGlobalSettings());
        expect(Object.keys(merged)).not.toHaveLength(0);
    });
    test('verify clearing the file cache works', () => {
        CSpellSettingsServer_1.mergeSettings(DefaultSettings_1.getDefaultSettings(), CSpellSettingsServer_1.getGlobalSettings());
        expect(CSpellSettingsServer_1.getCachedFileSize()).toBeGreaterThan(0);
        CSpellSettingsServer_1.clearCachedSettingsFiles();
        expect(CSpellSettingsServer_1.getCachedFileSize()).toBe(0);
    });
    test('the loaded defaults contain expected settings', () => {
        const settings = DefaultSettings_1.getDefaultSettings();
        const sources = CSpellSettingsServer_1.getSources(settings);
        const sourceNames = sources.map((s) => s.name || '?');
        expect(sourceNames).toEqual(expect.arrayContaining([DefaultSettings_1._defaultSettings.name]));
    });
    test('loading circular imports (readSettings)', async () => {
        const configFile = path.join(samplesDir, 'linked/cspell.circularA.json');
        const config = CSpellSettingsServer_1.readSettings(configFile);
        expect(config === null || config === void 0 ? void 0 : config.ignorePaths).toEqual(expect.arrayContaining([
            {
                glob: 'node_modules',
                root: path.dirname(configFile),
                source: configFile,
            },
        ]));
        const errors = CSpellSettingsServer_1.extractImportErrors(config);
        expect(errors).toEqual([]);
        const sources = CSpellSettingsServer_1.getSources(config);
        expect(sources.length).toBe(2);
    });
    test('loading circular imports (loadConfig)', async () => {
        const configFile = path.join(samplesDir, 'linked/cspell.circularA.json');
        const config = await CSpellSettingsServer_1.loadConfig(configFile);
        expect(config === null || config === void 0 ? void 0 : config.ignorePaths).toEqual(expect.arrayContaining([
            {
                glob: 'node_modules',
                root: path.dirname(configFile),
                source: configFile,
            },
        ]));
        const errors = CSpellSettingsServer_1.extractImportErrors(config);
        expect(errors).toEqual([]);
        const sources = CSpellSettingsServer_1.getSources(config);
        expect(sources.length).toBe(2);
    });
});
describe('Validate Overrides', () => {
    test.each `
        file                               | glob                                      | expected
        ${'nested/dir/spell.test.ts'}      | ${'nested/**'}                            | ${false /* nested/** tests against the current dir not __dirname */}
        ${'nested/dir/spell.test.ts'}      | ${{ glob: 'nested/**', root: __dirname }} | ${true /* setting the root to __dirname will allow this to be true. */}
        ${'nested/dir/spell.test.ts'}      | ${'nested'}                               | ${true}
        ${'nested/dir/spell.test.ts'}      | ${'*.ts'}                                 | ${true}
        ${'nested/dir/spell.test.ts'}      | ${'**/*.ts'}                              | ${true}
        ${'nested/dir/spell.test.ts'}      | ${['**/*.ts']}                            | ${true}
        ${'nested/dir/spell.test.ts'}      | ${['**/dir/**/*.ts']}                     | ${true}
        ${'nested/dir/spell.test.js'}      | ${['**/*.ts']}                            | ${false}
        ${'nested/dir/spell.test.js'}      | ${['*.ts', '*.test.js']}                  | ${true}
        ${'/cspell-dicts/nl_NL/Dutch.txt'} | ${'**/nl_NL/**'}                          | ${false /* the file is a root filename */}
        ${'cspell-dicts/nl_NL/Dutch.txt'}  | ${'**/nl_NL/**'}                          | ${true}
    `('checkFilenameMatchesGlob "$file" against "$glob" expect: $expected', ({ file, glob, expected }) => {
        file = path.resolve(__dirname, file);
        expect(CSpellSettingsServer_1.checkFilenameMatchesGlob(file, glob)).toBe(expected);
    });
    test.each `
        file                          | expected
        ${'nested/dir/spell.test.ts'} | ${{ languageId: 'typescript' }}
        ${'nested/docs/NL/myDoc.lex'} | ${{ languageId: 'lex', language: 'en' }}
        ${'nested/docs/NL/myDoc.txt'} | ${{ languageId: 'plaintext', language: 'en,nl' }}
    `('calcOverrideSettings $file expected $expected', ({ file, expected }) => {
        file = path.resolve(__dirname, file);
        const r = CSpellSettingsServer_1.calcOverrideSettings(sampleSettings, file);
        expect(r).toEqual(expect.objectContaining(expected));
    });
});
describe('Validate Glob resolution', () => {
    beforeAll(() => {
        delete process.env[CSpellSettingsServer_1.ENV_CSPELL_GLOB_ROOT];
    });
    test('normalized settings', () => {
        expect(sampleSettings).not.toEqual(sampleSettingsV1);
        expect(sampleSettings.globRoot).not.toEqual(sampleSettingsV1.globRoot);
        expect(sampleSettings.globRoot).toBe(__dirname);
        expect(sampleSettingsV1.globRoot).toContain(process.cwd());
        expect(sampleSettings.ignorePaths).toEqual(expect.arrayContaining([
            { glob: 'node_modules', root: sampleSettings.globRoot, source: sampleSettingsFilename },
        ]));
        expect(sampleSettingsV1.ignorePaths).toEqual(expect.arrayContaining([
            { glob: 'node_modules', root: sampleSettingsV1.globRoot, source: sampleSettingsFilename },
        ]));
    });
    test('Using ENV_CSPELL_GLOB_ROOT as __dirname', () => {
        process.env[CSpellSettingsServer_1.ENV_CSPELL_GLOB_ROOT] = __dirname;
        const settingsV = normalizeSettings(rawSampleSettings, __filename);
        const settingsV1 = normalizeSettings(rawSampleSettingsV1, __filename);
        expect(settingsV).toEqual(sampleSettings);
        expect(settingsV1).not.toEqual(sampleSettingsV1);
        delete settingsV1.version;
        expect(settingsV1).toEqual(sampleSettings);
    });
    test('Using ENV_CSPELL_GLOB_ROOT as without shared hierarchy', () => {
        process.env[CSpellSettingsServer_1.ENV_CSPELL_GLOB_ROOT] = path.resolve(__dirname, '../../samples');
        const settingsV = normalizeSettings(rawSampleSettings, __filename);
        const settingsV1 = normalizeSettings(rawSampleSettingsV1, __filename);
        expect(settingsV).not.toEqual(sampleSettings);
        expect(settingsV1).not.toEqual(sampleSettingsV1);
        delete settingsV1.version;
        expect(settingsV1).toEqual(settingsV);
    });
    test('globs with relative globRoot', async () => {
        const configFilename = path.resolve(samplesDir, 'cspell.relative-glob-root.json');
        const configDir = path.dirname(configFilename);
        const config = await CSpellSettingsServer_1.loadConfig(configFilename);
        expect(config).toEqual(oc({
            ignorePaths: expect.arrayContaining([
                {
                    glob: 'node_modules',
                    root: path.resolve(configDir, '../../..'),
                    source: configFilename,
                },
            ]),
        }));
    });
    test('globs from config file (search)', async () => {
        const config = await CSpellSettingsServer_1.searchForConfig(__dirname);
        expect(config === null || config === void 0 ? void 0 : config.ignorePaths).toEqual(expect.arrayContaining([
            {
                glob: 'node_modules/**',
                root: rootCspellLib,
                source: path.join(rootCspellLib, 'cspell.config.json'),
            },
        ]));
    });
    test('globs from config file (readSettings)', async () => {
        const configFile = path.join(rootCspellLib, 'cspell.config.json');
        const config = CSpellSettingsServer_1.readSettings(configFile);
        expect(config === null || config === void 0 ? void 0 : config.ignorePaths).toEqual(expect.arrayContaining([
            {
                glob: 'node_modules/**',
                root: rootCspellLib,
                source: configFile,
            },
        ]));
    });
});
describe('Validate search/load config files', () => {
    function importRefWithError(filename) {
        return {
            filename,
            error: new Error(`Failed to find config file at: "${filename}"`),
        };
    }
    function readError(filename) {
        return {
            filename,
            error: new Error(`Failed to read config file: "${filename}"`),
        };
    }
    function cfg(filename, values = {}) {
        const __importRef = importFileRef(filename);
        return {
            __importRef,
            ...values,
        };
    }
    /**
     * Create an ImportFileRef that has an `error` field.
     */
    function importFileRef(filenameOrRef) {
        const { filename, error } = iRef(filenameOrRef);
        return { filename, error };
    }
    /**
     * Create an ImportFileRef with an optional `error` field.
     */
    function iRef(filenameOrRef) {
        return typeof filenameOrRef === 'string' ? { filename: filenameOrRef } : filenameOrRef;
    }
    function s(filename) {
        return relSamples(filename);
    }
    test.each `
        dir                         | expectedConfig                                                      | expectedImportErrors
        ${samplesSrc}               | ${cfg(s('.cspell.json'))}                                           | ${[]}
        ${s('bug-fixes/bug345.ts')} | ${cfg(s('bug-fixes/cspell.json'))}                                  | ${[]}
        ${s('linked')}              | ${cfg(s('linked/cspell.config.js'))}                                | ${[]}
        ${s('yaml-config')}         | ${cfg(s('yaml-config/cspell.yaml'), { id: 'Yaml Example Config' })} | ${['cspell-imports.json']}
    `('Search from $dir', async ({ dir, expectedConfig, expectedImportErrors }) => {
        var _a;
        const searchResult = await CSpellSettingsServer_1.searchForConfig(dir);
        expect(searchResult).toEqual(expect.objectContaining(expectedConfig));
        if (searchResult === null || searchResult === void 0 ? void 0 : searchResult.__importRef) {
            const loadResult = await CSpellSettingsServer_1.loadConfig((_a = searchResult.__importRef) === null || _a === void 0 ? void 0 : _a.filename);
            expect(loadResult).toEqual(searchResult);
        }
        const errors = CSpellSettingsServer_1.extractImportErrors(searchResult || {});
        expect(errors).toHaveLength(expectedImportErrors.length);
        expect(errors).toEqual(expect.arrayContaining(expectedImportErrors.map((filename) => expect.objectContaining({ filename: expect.stringContaining(filename) }))));
    });
    test.each `
        file                               | expectedConfig
        ${samplesSrc}                      | ${cfg(importRefWithError(samplesSrc))}
        ${s('bug-fixes')}                  | ${cfg(importRefWithError(s('bug-fixes')))}
        ${s('linked/cspell.config.js')}    | ${cfg(s('linked/cspell.config.js'))}
        ${s('js-config/cspell.config.js')} | ${cfg(s('js-config/cspell.config.js'))}
    `('Load from $file', async ({ file, expectedConfig }) => {
        const searchResult = await CSpellSettingsServer_1.loadConfig(file);
        expect(searchResult).toEqual(expectedConfig ? expect.objectContaining(expectedConfig) : undefined);
    });
    test.each `
        file                                  | expectedConfig
        ${samplesSrc}                         | ${cfg(readError(samplesSrc))}
        ${s('bug-fixes')}                     | ${cfg(readError(s('bug-fixes')))}
        ${s('linked/cspell.config.js')}       | ${cfg(s('linked/cspell.config.js'), { description: 'cspell.config.js file in samples/linked', import: ['./cspell-imports.json'] })}
        ${s('js-config/cspell.config.js')}    | ${cfg(s('js-config/cspell.config.js'), { description: 'cspell.config.js file in samples/js-config' })}
        ${s('js-config/cspell-no-export.js')} | ${cfg(s('js-config/cspell-no-export.js'))}
        ${s('js-config/cspell-bad.js')}       | ${cfg(readError(s('js-config/cspell-bad.js')))}
    `('ReadRawSettings from $file', async ({ file, expectedConfig }) => {
        const searchResult = await CSpellSettingsServer_1.readRawSettings(file);
        expect(searchResult).toEqual(expectedConfig ? expect.objectContaining(expectedConfig) : undefined);
    });
});
function oc(v) {
    return expect.objectContaining(v);
}
function relSamples(file) {
    return path.resolve(samplesDir, file);
}
const rawSampleSettings = {
    language: 'en',
    languageId: 'plaintext',
    ignorePaths: ['node_modules'],
    overrides: [
        {
            filename: '**/*.ts',
            languageId: 'typescript',
        },
        {
            filename: '**/*.lex',
            languageId: 'lex',
        },
        {
            filename: '**/NL/*.txt',
            language: 'en,nl',
        },
    ],
};
const rawSampleSettingsV1 = { ...rawSampleSettings, version: '0.1' };
const sampleSettingsFilename = __filename;
const sampleSettings = normalizeSettings(rawSampleSettings, sampleSettingsFilename);
const sampleSettingsV1 = normalizeSettings(rawSampleSettingsV1, sampleSettingsFilename);
//# sourceMappingURL=CSpellSettingsServer.test.js.map