"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-non-null-assertion */
const DictSettings = __importStar(require("./DictionarySettings"));
const fsp = __importStar(require("fs-extra"));
const path = __importStar(require("path"));
const os = __importStar(require("os"));
const DefaultSettings_1 = require("./DefaultSettings");
const defaultSettings = DefaultSettings_1.getDefaultSettings();
describe('Validate DictionarySettings', () => {
    test('expects default to not be empty', () => {
        const mapDefs = DictSettings.filterDictDefsToLoad(['php', 'wordsEn', 'unknown', 'en_us'], defaultSettings.dictionaryDefinitions);
        const files = mapDefs.map((a) => a[1]).map((def) => def.name);
        expect(mapDefs).toHaveLength(2);
        expect(files.filter((a) => a.includes('php'))).toHaveLength(1);
        expect(files.filter((a) => a.includes('wordsEn'))).toHaveLength(0);
        expect(files.filter((a) => a.includes('en_us'))).toHaveLength(1);
        expect(files.filter((a) => a.includes('unknown'))).toHaveLength(0);
    });
    test('tests exclusions and empty ids', () => {
        const ids = [
            'php',
            'cpp',
            'wordsEn',
            '  ',
            'unknown',
            '!cpp',
            'en_us',
        ];
        const expected = ['php', 'en_us'].sort();
        const mapDefs = DictSettings.filterDictDefsToLoad(ids, defaultSettings.dictionaryDefinitions);
        const dicts = mapDefs
            .map((a) => a[1])
            .map((def) => def.name)
            .sort();
        expect(dicts).toEqual(expected);
    });
    test('tests that the files exist', () => {
        const defaultDicts = defaultSettings.dictionaryDefinitions;
        const dictIds = defaultDicts.map((def) => def.name);
        const mapDefs = DictSettings.filterDictDefsToLoad(dictIds, defaultSettings.dictionaryDefinitions);
        const access = mapDefs
            .map(([_, def]) => def)
            .map((def) => def.path)
            .map((path) => fsp.access(path));
        expect(mapDefs.length).toBeGreaterThan(0);
        return Promise.all(access);
    });
    test('tests default dictionary settings have been normalized', () => {
        const { dictionaryDefinitions } = defaultSettings;
        expect(dictionaryDefinitions === null || dictionaryDefinitions === void 0 ? void 0 : dictionaryDefinitions.length).toBeGreaterThan(1);
        dictionaryDefinitions === null || dictionaryDefinitions === void 0 ? void 0 : dictionaryDefinitions.forEach((def) => {
            expect(DictSettings.isDictionaryDefinitionWithSource(def)).toBe(true);
            expect(path.isAbsolute(def.path || '')).toBe(true);
        });
    });
    test('tests normalizing home dir', () => {
        const pathToConfig = './cspell.json';
        const basePath = path.join('some', 'dir', 'words.txt');
        const absolutePath = path.join(os.homedir(), basePath);
        const def = {
            name: 'words',
            path: path.join('~', basePath),
        };
        const nDef = DictSettings.normalizePathForDictDef(def, pathToConfig);
        expect(nDef).toEqual({
            name: 'words',
            path: absolutePath,
            __source: pathToConfig,
        });
        const legacyDef = {
            name: 'words',
            path: path.dirname(path.join('~', basePath)),
            file: path.basename(basePath),
        };
        const nLegacyDef = DictSettings.normalizePathForDictDef(legacyDef, pathToConfig);
        expect(nLegacyDef).toEqual(nDef);
    });
    test('Double normalize', () => {
        const configFile = './cspell.json';
        const def = {
            name: 'Text Dict',
            path: './words.txt',
        };
        const normalizedDef = DictSettings.normalizePathForDictDef(def, configFile);
        expect(DictSettings.isDictionaryDefinitionWithSource(normalizedDef)).toBe(true);
        expect(normalizedDef).toEqual(expect.objectContaining({ __source: configFile }));
        const normalizedDef2 = DictSettings.normalizePathForDictDef(normalizedDef, configFile);
        expect(normalizedDef2).toBe(normalizedDef);
        expect(() => DictSettings.normalizePathForDictDef(normalizedDef, './different.config.json')).toThrowError('Trying to normalize a dictionary definition with a different source.');
    });
});
//# sourceMappingURL=DictionarySettings.test.js.map