"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const GlobalSettings_1 = require("./GlobalSettings");
const configstore_1 = __importDefault(require("configstore"));
// eslint-disable-next-line jest/no-mocks-import
const configstore_2 = require("../__mocks__/configstore");
const mockLog = jest.fn();
console.log = mockLog;
jest.mock('configstore');
const mockConfigstore = configstore_1.default;
describe('Validate GlobalSettings', () => {
    beforeEach(() => {
        mockConfigstore.mockClear();
        mockLog.mockClear();
        configstore_2.clearMocks();
        configstore_2.clearData();
    });
    test('getGlobalConfigPath', () => {
        expect(GlobalSettings_1.getGlobalConfigPath()).toEqual(expect.stringMatching(/cspell\.json$/));
    });
    test('getRawGlobalSettings', () => {
        const path = GlobalSettings_1.getGlobalConfigPath();
        const s = GlobalSettings_1.getRawGlobalSettings();
        expect(s).toEqual({
            source: {
                name: 'CSpell Configstore',
                filename: path,
            },
        });
        expect(mockLog).not.toHaveBeenCalled();
    });
    test('getRawGlobalSettings with Error', () => {
        configstore_2.mockAll.mockImplementation(() => {
            throw new Error('fail');
        });
        const s = GlobalSettings_1.getRawGlobalSettings();
        expect(s).toEqual({
            source: {
                name: 'CSpell Configstore',
                filename: undefined,
            },
        });
        expect(mockLog).toHaveBeenCalledWith(expect.any(Error));
    });
    test('writeRawGlobalSettings', () => {
        const s = GlobalSettings_1.getRawGlobalSettings();
        const updated = { ...s, import: ['hello'], extra: { name: 'extra', value: 'ok' } };
        GlobalSettings_1.writeRawGlobalSettings(updated);
        expect(configstore_2.mockSetData).toHaveBeenCalledWith({
            import: ['hello'],
        });
    });
    test('writeRawGlobalSettings with Error', () => {
        const updated = { import: ['hello'] };
        configstore_2.mockSetData.mockImplementation(() => {
            throw new Error('fail');
        });
        const error1 = GlobalSettings_1.writeRawGlobalSettings(updated);
        expect(error1).toBeInstanceOf(Error);
        configstore_2.mockSetData.mockImplementation(() => {
            throw 'fail';
        });
        const error2 = GlobalSettings_1.writeRawGlobalSettings(updated);
        expect(error2).toBeInstanceOf(Error);
    });
});
//# sourceMappingURL=GlobalSettings.test.js.map