"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const DictionaryLoader_1 = require("./DictionaryLoader");
const path = __importStar(require("path"));
jest.mock('../util/logger');
const root = path.join(__dirname, '..', '..');
const samples = path.join(root, 'samples');
describe('Validate DictionaryLoader', () => {
    const errorENOENT = { code: 'ENOENT' };
    const unknownFormatError = new Error('Unknown file format');
    test.each `
        filename                | expectedError
        ${'./notfound.txt'}     | ${errorENOENT}
        ${'./notfound.txt.gz'}  | ${errorENOENT}
        ${'./notfound.trie'}    | ${unknownFormatError}
        ${'./notfound.trie.gz'} | ${unknownFormatError}
    `('load not found $filename', async ({ filename, expectedError }) => {
        const def = {
            path: filename,
            name: filename,
        };
        const dictionary = DictionaryLoader_1.testing.load(filename, def);
        await expect(dictionary).rejects.toEqual(expect.objectContaining(expectedError));
    });
    test.each `
        filename                | expectedError
        ${'./notfound.txt'}     | ${errorENOENT}
        ${'./notfound.txt.gz'}  | ${errorENOENT}
        ${'./notfound.trie'}    | ${unknownFormatError}
        ${'./notfound.trie.gz'} | ${unknownFormatError}
    `('loadEntry not found $filename', async ({ filename, expectedError }) => {
        const def = {
            path: filename,
            name: filename,
        };
        const entry = DictionaryLoader_1.testing.loadEntry(filename, def);
        await expect(entry.state).resolves.toEqual(expect.objectContaining(expectedError));
        await expect(entry.dictionary).resolves.not.toBe(undefined);
    });
    test.each `
        filename
        ${'./notfound.txt'}
        ${'./notfound.txt.gz'}
        ${'./notfound.trie'}
        ${'./notfound.trie.gz'}
    `('loadDictionary not found $filename', async ({ filename }) => {
        var _a;
        const def = {
            path: filename,
            name: filename,
        };
        const dict = await DictionaryLoader_1.loadDictionary(filename, def);
        expect((_a = dict.getErrors) === null || _a === void 0 ? void 0 : _a.call(dict)).toHaveLength(1);
    });
    const csharp = require.resolve('@cspell/dict-csharp/csharp.txt.gz');
    test.each `
        testCase            | file                          | options          | word            | maxAge       | hasWord  | hasErrors
        ${'sample words'}   | ${sample('words.txt')}        | ${{}}            | ${'apple'}      | ${1}         | ${true}  | ${false}
        ${'sample words'}   | ${sample('words.txt')}        | ${{ type: 5 }}   | ${'apple'}      | ${1}         | ${true}  | ${false}
        ${'sample words'}   | ${sample('words.txt')}        | ${{ type: 'S' }} | ${'pear'}       | ${undefined} | ${true}  | ${false}
        ${'sample words'}   | ${sample('words.txt')}        | ${{ type: 'C' }} | ${'strawberry'} | ${1}         | ${true}  | ${false}
        ${'sample words'}   | ${sample('words.txt')}        | ${{}}            | ${'tree'}       | ${1}         | ${false} | ${false}
        ${'unknown loader'} | ${sample('words.txt')}        | ${{ type: 5 }}   | ${'apple'}      | ${1}         | ${true}  | ${false}
        ${'missing file'}   | ${'./missing_dictionary.txt'} | ${{}}            | ${'apple'}      | ${1}         | ${false} | ${true}
        ${'missing file'}   | ${'./missing_dictionary.txt'} | ${{ type: 'S' }} | ${'pear'}       | ${undefined} | ${false} | ${true}
        ${'missing file'}   | ${'./missing_dictionary.txt'} | ${{ type: 'C' }} | ${'strawberry'} | ${1}         | ${false} | ${true}
        ${'missing file'}   | ${'./missing_dictionary.txt'} | ${{}}            | ${'tree'}       | ${1}         | ${false} | ${true}
        ${'csharp type {}'} | ${csharp}                     | ${{}}            | ${'const'}      | ${1}         | ${true}  | ${false}
        ${'csharp type S'}  | ${csharp}                     | ${{ type: 'S' }} | ${'const'}      | ${1}         | ${true}  | ${false}
        ${'csharp type C'}  | ${csharp}                     | ${{ type: 'C' }} | ${'const'}      | ${1}         | ${true}  | ${false}
    `('$testCase $word', async ({ file, options, word, maxAge, hasWord, hasErrors, }) => {
        var _a;
        await DictionaryLoader_1.refreshCacheEntries(maxAge, Date.now());
        const d = await DictionaryLoader_1.loadDictionary(file, options);
        expect(d.has(word)).toBe(hasWord);
        expect(!!((_a = d.getErrors) === null || _a === void 0 ? void 0 : _a.call(d).length)).toBe(hasErrors);
    });
});
function sample(file) {
    return path.join(samples, file);
}
//# sourceMappingURL=DictionaryLoader.test.js.map