"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Trie = __importStar(require("cspell-trie-lib"));
const SpellingDictionaryCollection_1 = require("./SpellingDictionaryCollection");
const SpellingDictionaryMethods_1 = require("./SpellingDictionaryMethods");
const createSpellingDictionary_1 = require("./createSpellingDictionary");
const SpellingDictionaryFromTrie_1 = require("./SpellingDictionaryFromTrie");
const SpellingDictionaryError_1 = require("./SpellingDictionaryError");
describe('Verify using multiple dictionaries', () => {
    const wordsA = [
        '',
        'apple',
        'banana',
        'orange',
        'pear',
        'pineapple',
        'mango',
        'avocado',
        'grape',
        'strawberry',
        'blueberry',
        'blackberry',
    ];
    const wordsB = ['ape', 'lion', 'tiger', 'elephant', 'monkey', 'gazelle', 'antelope', 'aardvark', 'hyena'];
    const wordsC = ['ant', 'snail', 'beetle', 'worm', 'stink bug', 'centipede', 'millipede', 'flea', 'fly'];
    const wordsD = ['red*', 'green*', 'blue*', 'pink*', 'black*', '*berry', '+-fruit'];
    test('checks for existence', async () => {
        const dicts = await Promise.all([
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsD, 'wordsD', 'test'),
        ]);
        const dictCollection = new SpellingDictionaryCollection_1.SpellingDictionaryCollection(dicts, 'test', ['Avocado']);
        expect(dictCollection.has('mango')).toBe(true);
        expect(dictCollection.has('tree')).toBe(false);
        expect(dictCollection.has('avocado')).toBe(false);
        expect(dictCollection.has('')).toBe(false);
        expect(dictCollection.has('red-fruit')).toBe(true);
        expect(dictCollection.has('-fruit')).toBe(false);
        expect(dictCollection.has('blackberry')).toBe(true);
        expect(dictCollection.size).toBeGreaterThanOrEqual(wordsA.length - 1 + wordsB.length + wordsC.length);
    });
    test('checks mapWord is identity', async () => {
        const dicts = await Promise.all([createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test')]);
        const dictCollection = new SpellingDictionaryCollection_1.SpellingDictionaryCollection(dicts, 'test', []);
        expect(dictCollection.mapWord('Hello')).toBe('Hello');
    });
    test('checks for suggestions', async () => {
        var _a;
        const trie = new SpellingDictionaryFromTrie_1.SpellingDictionaryFromTrie(Trie.Trie.create(wordsA), 'wordsA');
        const dicts = await Promise.all([
            trie,
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
            createSpellingDictionary_1.createFailedToLoadDictionary(new SpellingDictionaryError_1.SpellingDictionaryLoadError('./missing.txt', { name: 'error', path: './missing.txt' }, new Error('error'), 'failed to load')),
        ]);
        const dictCollection = SpellingDictionaryCollection_1.createCollection(dicts, 'test', ['Avocado']);
        expect((_a = dictCollection.getErrors) === null || _a === void 0 ? void 0 : _a.call(dictCollection)).toHaveLength(1);
        const sugsForTango = dictCollection.suggest('tango', 10);
        expect(sugsForTango).toHaveLength(1);
        expect(sugsForTango[0].word).toEqual('mango');
        // make sure there is only one mango suggestion.
        expect(sugsForTango.map((a) => a.word).filter((a) => a === 'mango')).toEqual(['mango']);
    });
    test('checks for compound suggestions', async () => {
        // Add "wordsA" twice, once as a compound dictionary and once as a normal dictionary.
        const trie = new SpellingDictionaryFromTrie_1.SpellingDictionaryFromTrie(Trie.Trie.create(wordsA), 'wordsA');
        trie.options.useCompounds = true;
        const dicts = await Promise.all([
            trie,
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        ]);
        // cspell:ignore appletango applemango
        const dictCollection = SpellingDictionaryCollection_1.createCollection(dicts, 'test', ['Avocado']);
        const sugResult = dictCollection.suggest('appletango', 10, SpellingDictionaryMethods_1.CompoundWordsMethod.SEPARATE_WORDS);
        const sugs = sugResult.map((a) => a.word);
        expect(sugs).toHaveLength(10);
        expect(sugs).toContain('apple+mango');
        expect(sugs).toContain('apple mango');
    });
    test('checks for compound suggestions with numbChanges', async () => {
        const trie = new SpellingDictionaryFromTrie_1.SpellingDictionaryFromTrie(Trie.Trie.create(wordsA), 'wordsA');
        const dicts = await Promise.all([
            trie,
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        ]);
        // cspell:ignore appletango applemango
        const dictCollection = SpellingDictionaryCollection_1.createCollection(dicts, 'test', ['Avocado']);
        const sugResult = dictCollection.suggest('appletango', 10, SpellingDictionaryMethods_1.CompoundWordsMethod.SEPARATE_WORDS, 2);
        const sugs = sugResult.map((a) => a.word);
        expect(sugs).toHaveLength(1);
        expect(sugs).not.toContain('apple+mango');
        expect(sugs).toContain('apple mango');
    });
    test('checks for suggestions with flagged words', async () => {
        const dicts = await Promise.all([
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        ]);
        const dictCollection = SpellingDictionaryCollection_1.createCollection(dicts, 'test', ['Avocado']);
        const sugs = dictCollection.suggest('avocado', 10);
        expect(sugs.map((r) => r.word)).not.toContain('avocado');
    });
    test('checks for suggestions from mixed sources', async () => {
        const dicts = await Promise.all([
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        ]);
        const dictCollection = new SpellingDictionaryCollection_1.SpellingDictionaryCollection(dicts, 'test', []);
        expect(dictCollection.has('mango')).toBe(true);
        expect(dictCollection.has('lion')).toBe(true);
        expect(dictCollection.has('ant')).toBe(true);
        const sugsForTango = dictCollection.suggest('tango', 10);
        expect(sugsForTango).toHaveLength(1);
        expect(sugsForTango[0].word).toBe('mango');
        // make sure there is only one mango suggestion.
        expect(sugsForTango.map((a) => a.word).filter((a) => a === 'mango')).toEqual(['mango']);
        // cspell:ignore cellipede
        const sugsForCellipede = dictCollection.suggest('cellipede', 5);
        expect(sugsForCellipede).toHaveLength(2);
        expect(sugsForCellipede.map((s) => s.word)).toContain('centipede');
        expect(sugsForCellipede.map((s) => s.word)).toContain('millipede');
    });
    test('creates using createCollectionP', async () => {
        var _a;
        const dicts = [
            createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
            createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        ];
        const dictCollection = await SpellingDictionaryCollection_1.createCollectionP(dicts, 'test', []);
        expect(dictCollection.has('mango')).toBe(true);
        expect(dictCollection.has('tree')).toBe(false);
        const sugs = dictCollection.suggest('mangos', 4);
        const sugWords = sugs.map((s) => s.word);
        expect(sugWords[0]).toBe('mango');
        expect((_a = dictCollection.getErrors) === null || _a === void 0 ? void 0 : _a.call(dictCollection)).toHaveLength(0);
    });
});
describe('Validate looking up words', () => {
    const wordsA = [
        '',
        'apple',
        'banana',
        'orange',
        'pear',
        'pineapple',
        'mango',
        'avocado',
        'grape',
        'strawberry',
        'blueberry',
        'blackberry',
    ];
    const wordsB = ['ape', 'lion', 'tiger', 'elephant', 'monkey', 'gazelle', 'antelope', 'aardvark', 'hyena'];
    const wordsC = ['ant', 'snail', 'beetle', 'worm', 'stink bug', 'centipede', 'millipede', 'flea', 'fly'];
    const wordsD = ['red*', 'green*', 'blue*', 'pink*', 'black*', '*berry', '+-fruit'];
    const cities = ['Seattle', 'Berlin', 'Amsterdam', 'Rome', 'London', 'Mumbai', 'Tokyo'];
    const testDicts = [
        createSpellingDictionary_1.createSpellingDictionary(wordsA, 'wordsA', 'test'),
        createSpellingDictionary_1.createSpellingDictionary(wordsB, 'wordsB', 'test'),
        createSpellingDictionary_1.createSpellingDictionary(wordsC, 'wordsC', 'test'),
        createSpellingDictionary_1.createSpellingDictionary(wordsD, 'wordsD', 'test'),
        createSpellingDictionary_1.createSpellingDictionary(cities, 'cities', 'test'),
    ];
    const testDictCollection = new SpellingDictionaryCollection_1.SpellingDictionaryCollection(testDicts, 'test', ['Avocado']);
    test.each `
        word             | found
        ${'Amsterdam'}   | ${true}
        ${'amsterdam'}   | ${true}
        ${'Black'}       | ${true}
        ${'black-fruit'} | ${true}
    `('Has word "$word" $found', ({ word, found }) => {
        expect(testDictCollection.has(word)).toBe(found);
    });
});
//# sourceMappingURL=SpellingDictionaryCollection.test.js.map