"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Comparable_1 = require("./Comparable");
describe('Validate Comparable', () => {
    test('compare', () => {
        expect(Comparable_1.compare(1, 2)).toBeLessThan(0);
        expect(Comparable_1.compare(1, 1)).toBe(0);
        expect(Comparable_1.compare(2, 1)).toBeGreaterThan(0);
        expect(Comparable_1.compare('a', 'b')).toBeLessThan(0);
        expect(Comparable_1.compare('a', 'a')).toBe(0);
        expect(Comparable_1.compare('b', 'a')).toBeGreaterThan(0);
        expect(Comparable_1.compare('a', undefined)).toBeLessThan(0);
        expect(Comparable_1.compare(undefined, undefined)).toBe(0);
        expect(Comparable_1.compare(undefined, 'a')).toBeGreaterThan(0);
        expect(Comparable_1.compare(null, undefined)).toBeLessThan(0);
        expect(Comparable_1.compare(undefined, null)).toBeGreaterThan(0);
        expect(Comparable_1.compare('a', null)).toBeLessThan(0);
        expect(Comparable_1.compare(null, null)).toBe(0);
        expect(Comparable_1.compare(null, 'a')).toBeGreaterThan(0);
        expect(Comparable_1.compare(new Date('2018-01-01'), new Date('2018-01-02'))).toBeLessThan(0);
        expect(Comparable_1.compare(new Date('2018-01-01'), new Date('2018-01-01'))).toBe(0);
        expect(Comparable_1.compare(new Date('2018-01-02'), new Date('2018-01-01'))).toBeGreaterThan(0);
    });
    test('compareBy', () => {
        expect(samples()
            .sort(Comparable_1.compareBy('name', 'value'))
            .map((a) => a.id)).toEqual([0, 1, 3, 2, 4]);
        expect(samples()
            .sort(Comparable_1.compareBy('value', 'name'))
            .map((a) => a.id)).toEqual([3, 4, 2, 0, 1]);
        expect(samples()
            .sort(Comparable_1.compareBy('name', 'maybe'))
            .map((a) => a.id)).toEqual([0, 1, 2, 3, 4]);
        // Expect undefined to be at the end.
        expect(samples()
            .sort(Comparable_1.compareBy('maybe', 'name', 'value'))
            .map((a) => a.id)).toEqual([0, 3, 2, 1, 4]);
    });
    test('reverse', () => {
        const cmp = (a, b) => a - b;
        expect(Comparable_1.reverse(cmp)(1, 5)).toBe(4);
        expect(Comparable_1.reverse(cmp)(5, 5)).toBe(0);
        expect(Comparable_1.reverse(cmp)(10, 5)).toBe(-5);
    });
    test('compareEach', () => {
        expect(samples()
            .sort(Comparable_1.compareEach(Comparable_1.compareBy('name'), Comparable_1.compareBy('value')))
            .map((a) => a.id)).toEqual([0, 1, 3, 2, 4]);
        expect(samples()
            .sort(Comparable_1.compareEach(Comparable_1.compareByRev('name'), Comparable_1.compareBy('value')))
            .map((a) => a.id)).toEqual([4, 3, 2, 0, 1]);
    });
});
function samples() {
    return [
        { name: 'A', value: 42, maybe: 5 },
        { name: 'A', value: 402, maybe: undefined },
        { name: 'B', value: 20, maybe: 10 },
        { name: 'B', value: 2, maybe: 10 },
        { name: 'C', value: 2, maybe: undefined },
    ].map((v, id) => ({ id, ...v }));
}
//# sourceMappingURL=Comparable.test.js.map